diff src/share/vm/code/codeBlob.hpp @ 21559:be896a1983c0

recast all Graal native code as JVMCI code (JBS:GRAAL-53)
author Doug Simon <doug.simon@oracle.com>
date Thu, 28 May 2015 15:36:48 +0200
parents 33a783b15758
children
line wrap: on
line diff
--- a/src/share/vm/code/codeBlob.hpp	Wed May 27 13:43:27 2015 +0200
+++ b/src/share/vm/code/codeBlob.hpp	Thu May 28 15:36:48 2015 +0200
@@ -105,7 +105,7 @@
 
   virtual bool is_compiled_by_c2() const         { return false; }
   virtual bool is_compiled_by_c1() const         { return false; }
-  virtual bool is_compiled_by_graal() const      { return false; }
+  virtual bool is_compiled_by_jvmci() const      { return false; }
 
   // Casting
   nmethod* as_nmethod_or_null()                  { return is_nmethod() ? (nmethod*) this : NULL; }
@@ -357,8 +357,8 @@
 
   int _unpack_with_exception_in_tls;
 
 #ifdef GRAAL
   // (thomaswue) Offset when Graal calls uncommon_trap.
   int _uncommon_trap_offset;
   int _implicit_exception_uncommon_trap_offset;
 #endif
@@ -416,8 +416,8 @@
   }
   address unpack_with_exception_in_tls() const   { return code_begin() + _unpack_with_exception_in_tls; }
 
 #ifdef GRAAL
   // (thomaswue) Offset when Graal calls uncommon_trap.
   void set_uncommon_trap_offset(int offset) {
     _uncommon_trap_offset = offset;
     assert(contains(code_begin() + _uncommon_trap_offset), "must be PC inside codeblob");
@@ -357,8 +357,8 @@
   int _unpack_with_exception_in_tls;
 
-#ifdef GRAAL
-  // (thomaswue) Offset when Graal calls uncommon_trap.
+#ifdef JVMCI
+  // (thomaswue) Offset when JVMCI calls uncommon_trap.
   int _uncommon_trap_offset;
   int _implicit_exception_uncommon_trap_offset;
@@ -416,8 +416,8 @@
   address unpack_with_exception_in_tls() const   { return code_begin() + _unpack_with_exception_in_tls; }
 
-#ifdef GRAAL
-  // (thomaswue) Offset when Graal calls uncommon_trap.
+#ifdef JVMCI
+  // (thomaswue) Offset when JVMCI calls uncommon_trap.
   void set_uncommon_trap_offset(int offset) {
     _uncommon_trap_offset = offset;